@@ -2,13 +2,13 @@ from django.contrib import admin
 
 from ..models import UserCheck
 from .forms import UserCheckAdminForm
-from .mixins import AdminBaseMixin
+from .mixins import AdminInlineBaseMixin
 
 
 __all__ = 'UserCheckInlineAdmin',
 
 
-class UserCheckInlineAdmin(AdminBaseMixin, admin.TabularInline):
+class UserCheckInlineAdmin(AdminInlineBaseMixin, admin.TabularInline):
     form = UserCheckAdminForm
     model = UserCheck
     extra = 0
