@@ -1,10 +1,10 @@
-from typing import Dict, Optional, Sequence
+from typing import Dict, List, Optional, Sequence
 from itertools import groupby
 from django.db import transaction
 from .models import UserCheck
 from .registry import CheckRegistry
 from .signals import state_changed
-from .dtos import UserIdType, UserCheckDTO, UserCheckStateDTO
+from .dtos import UserIdType, UserCheckStates, UserCheckDTO, UserCheckStateDTO
 
 from .utils import fix_check, get_checks_map
 
@@ -40,6 +40,9 @@ def set_checks(
     existing = get_checks_map(
         UserCheck.objects.filter(user_id__in=user_ids, reason__in=reasons)
     )
+    olds = UserCheckStateDTO.from_checks([
+        UserCheckDTO.from_model(check) for check in existing
+    ])
     updates: Sequence[UserCheck] = []
     creates: Sequence[UserCheck] = []
 
@@ -59,7 +62,7 @@ def set_checks(
 
         result = (created or []) + (updates or [])
 
-    send_checks_changed(result)
+    send_checks_changed(result, previous_states=olds)
 
     return result
 
@@ -88,8 +91,20 @@ def get_user_id(item: UserCheck):
     return item.user_id
 
 
-def send_checks_changed(checks: Sequence[UserCheck]):
+def send_checks_changed(
+    checks: Sequence[UserCheck],
+    # FIXME: Must not be this way.
+    # Checks state should store a changes history for every change happened.
+    # For me to get previous state at any time I need, not only when
+    # it was passed to me.
+    previous_states: Optional[UserCheckStates] = {}
+):
     grouped = groupby(sorted(checks, key=get_user_id), key=get_user_id)
 
     for user_id, items in grouped:
-        state_changed.send(UserCheck, user_id=user_id, items=list(items))
+        state_changed.send(
+            UserCheck,
+            user_id=user_id,
+            items=list(items),
+            previous_state=previous_states.get(user_id)
+        )
